@@ -70,6 +70,9 @@ public:
             else if ( ( pos = out.indexOf( "sox:      SoX v" ) ) >= 0 ) {
                 pos += 15;
             }
+            else if ( ( pos = out.indexOf( "sox:      SoX_ng v" ) ) >= 0 ) {
+                pos += 18;
+            }
             else if ( ( pos = out.indexOf( "sox: SoX v" ) ) >= 0 ) {
                 pos += 10;
             }
