@@ -18,7 +18,7 @@ K3b::UrlNavigator::UrlNavigator( KFilePlacesModel* model, QWidget* parent )
     : KUrlNavigator( model, QUrl::fromLocalFile(QDir::home().absolutePath()), parent )
 {
     // Currently we don't support burning from custom protocols so let's filter them out
-    KUrlNavigator::setCustomProtocols( QStringList() << "file" << "audiocd" );
+    KUrlNavigator::setSupportedSchemes( QStringList() << "file" << "audiocd" );
     
 	connect( this, SIGNAL(urlChanged(QUrl)), this, SLOT(urlActivated(QUrl)) );
 }
@@ -64,4 +64,4 @@ void K3b::UrlNavigator::urlActivated( const QUrl& url )
     emit activated( url );
 }
 
-
+#include "moc_k3burlnavigator.cpp"
