@@ -144,7 +144,7 @@ QString K3b::VideoDVDRippingDialog::Private::createFilename( const K3b::VideoDVD
         //
         if( pattern[i] == '%' && i+1 < pattern.length() ) {
             ++i; // skip the %
-            QChar c = pattern[i];
+            char c = pattern[i].toLatin1();
 
             //
             // first check if we have a long keyword instead of a one-char
@@ -239,7 +239,7 @@ QString K3b::VideoDVDRippingDialog::Private::createFilename( const K3b::VideoDVD
                 }
             }
 
-            switch( c.toLatin1() ) {
+            switch( c ) {
             case PATTERN_TITLE_NUMBER:
                 f.append( QString::number(info.title).rightJustified( 2, '0' ) );
                 break;
@@ -380,8 +380,10 @@ void K3b::VideoDVDRippingDialog::slotUpdateFilenames()
 
     for( TitleRipInfos::iterator it = d->titleRipInfos.begin(); it != d->titleRipInfos.end(); ++it ) {
         QString f = d->fsInfo.fixupPath( d->createFilename( it.value(), d->w->m_comboFilenamePattern->currentText() ) );
-        if( d->w->m_checkBlankReplace->isChecked() )
-            f.replace( QRegExp( "\\s" ), d->w->m_editBlankReplace->text() );
+        if( d->w->m_checkBlankReplace->isChecked() ) {
+            static const QRegularExpression rx( "\\s" );
+            f.replace( rx, d->w->m_editBlankReplace->text() );
+        }
         it.value().filename = baseDir + f;
 
         d->audioModel->setFileName( *it.key(), f );
@@ -506,12 +508,12 @@ void K3b::VideoDVDRippingDialog::slotStartClicked()
     }
 
     if( !filesToOverwrite.isEmpty() )
-        if( KMessageBox::questionYesNoList( this,
-                                            i18n("Do you want to overwrite these files?"),
-                                            filesToOverwrite,
-                                            i18n("Files Exist"),
-                                            KStandardGuiItem::overwrite(),
-                                            KStandardGuiItem::cancel() ) == KMessageBox::No )
+        if( KMessageBox::questionTwoActionsList( this,
+                                                 i18n("Do you want to overwrite these files?"),
+                                                 filesToOverwrite,
+                                                 i18n("Files Exist"),
+                                                 KStandardGuiItem::overwrite(),
+                                                 KStandardGuiItem::cancel() ) == KMessageBox::SecondaryAction )
             return;
 
 
@@ -559,4 +561,4 @@ void K3b::VideoDVDRippingDialog::slotStartClicked()
     close();
 }
 
-
+#include "moc_k3bvideodvdrippingdialog.cpp"
